@@ -13,7 +13,7 @@ from openmodule.dispatcher import SubscribingMessageDispatcher
 from openmodule.health import HealthHandlerType, Healthz, HealthPingMessage
 from openmodule.logging import init_logging
 from openmodule.messaging import get_pub_socket, get_sub_socket, receive_message_from_socket
-from openmodule.models import ZMQMessage
+from openmodule.models.base import ZMQMessage
 from openmodule.sentry import init_sentry
 from openmodule.threading import get_thread_wrapper
 
