@@ -4,7 +4,7 @@ from collections import namedtuple
 from enum import Enum
 from typing import Optional, Dict, Callable, Any
 
-from openmodule.models import ZMQMessage, OpenModuleModel
+from openmodule.models.base import ZMQMessage, OpenModuleModel
 
 from typing import TYPE_CHECKING
 
