@@ -117,5 +117,10 @@ class PresenceListener:
         if not self._gate_matches(message):
             return
         vehicle = vehicle_from_presence_message(message)
+
+        if message.change_vehicle_id:
+            self.log.info(f"Changing vehicle ID from {self.present_vehicles[message.gateway.gate].id} to "
+                          f"{message.vehicle_id}")
+            self.present_vehicles[message.gateway.gate] = vehicle
         self.log.debug("presence change: %s", vehicle)
         self.on_change(vehicle, message.gateway)
