@@ -100,12 +100,22 @@ class ModelTest(TestCase):
             Access(**kwargs)
         self.assertIn("recurrence is not valid", str(e.exception))
 
+        with self.assertRaises(ValueError) as e:
+            Access(**dict(
+                user="user",
+                category="filler-visitor-unexpected",
+                recurrence="DTSTART:20210108T160000\nFREQ=WEEKLY;BYDAY=FR",
+                duration=10,
+            ))
+        self.assertIn("set start timestamp when using recurrence", str(e.exception))
+
     def test_access_with_empty_string_recurrence_is_valid(self):
         access_as_dict = {
             "user": "user",
             "category": "filler-visitor-button",
             "start": time.time(),
             "recurrence": "",
+            "start": 0,
         }
         try:
             Access(**access_as_dict)
