@@ -1,17 +1,16 @@
-from typing import Dict, Optional, Any
-from unittest import TestCase
-
 import logging
 import os
 import socket
-import tempfile
 import warnings
-from pydantic import ValidationError
 from types import SimpleNamespace
+from typing import Optional, Any
+from unittest import TestCase
+
+from pydantic import ValidationError
 
 from openmodule import config
 from openmodule.config import validate_config_module
-from openmodule.models import OpenModuleModel
+from openmodule.models.base import OpenModuleModel
 from openmodule_test.core import OpenModuleCoreTestMixin
 from openmodule_test.files import temp_file
 
