@@ -3,7 +3,7 @@ from typing import Any
 from unittest import TestCase
 
 from openmodule.dispatcher import MessageDispatcher
-from openmodule.models import ZMQMessage
+from openmodule.models.base import ZMQMessage
 
 
 class MessageDispatcherBaseTest(TestCase):
