@@ -76,6 +76,25 @@ class PresenceTest(BasePresenceTest):
             self.assertEqual({}, self.presence.present_vehicles)
         self.assertIn("We are fake-leaving the currently present vehicle", str(cm))
 
+    def test_vehicle_id_change(self):
+        vehicle_0 = self.presence_sim.vehicle()
+        self.presence_sim.enter(vehicle_0)
+        self.on_enter.wait_for_call()
+        self.assertEqual(vehicle_0.vehicle_id, self.presence.present_vehicles["gate_in"].id)
+
+        vehicle_1 = self.presence_sim.vehicle().lpr("A", "G ARIVO1")
+        with self.assertLogs() as cm:
+            self.presence_sim.change_vehicle_and_id(vehicle_1)
+            self.on_change.wait_for_call()
+        self.assertIn("Changing vehicle ID", str(cm.output[0]))
+
+        self.assertEqual(vehicle_1.vehicle_id, self.presence.present_vehicles["gate_in"].id)
+
+        self.presence_sim.leave()
+        self.on_leave.wait_for_call()
+
+        self.assertIsNone(self.presence.present_vehicles.get("gate_in"))
+
     def test_normal(self):
         self.presence_sim.enter(self.presence_sim.vehicle().lpr("A", "G ARIVO1"))
         self.on_enter.wait_for_call()
@@ -94,7 +113,18 @@ class PresenceTest(BasePresenceTest):
         self.presence_sim.backward(vehicle)
         self.on_backward.wait_for_call()
 
-        self.presence_sim.change(vehicle)
+        self.presence_sim.enter(vehicle)
+        self.on_enter.wait_for_call()
+
+        vehicle_changed = vehicle.nfc("asdf")
+        self.presence_sim.change(vehicle_changed)
+        self.on_change.wait_for_call()
+        self.on_change.reset_call_count()
+
+        with self.assertRaises(AssertionError):
+            self.presence_sim.change_vehicle_and_id(vehicle_changed)
+
+        self.presence_sim.change_vehicle_and_id(self.presence_sim.vehicle().lpr("A", "G ARIVO1"))
         self.on_change.wait_for_call()
 
 
